const Gio = imports.gi.Gio;
const GLib = imports.gi.GLib;
const Me = imports.misc.extensionUtils.getCurrentExtension();
const ExtensionPath = Me.path;

function SettingsManager() {
    this._init();
};

SettingsManager.prototype = {
  _init: function() {
    
    this._conf = {};    
    this._file = Gio.file_new_for_path(ExtensionPath + '/settings.json');
    
    if(this._file.query_exists(null)) {
      [flag, data] = this._file.load_contents(null);
      
      if(flag) {
	this._conf = JSON.parse(data);
      }
    }
  },
  
  get_boolean: function(key) {
    return this._conf[key] || false;
  },
  
  set_boolean: function(key, value) {
    this._conf[key] = value;
    this._file.replace_contents(JSON.stringify(this._conf), null, false, 0, null);
  }
};

function Hash() {
  this._init.apply(this, arguments);
}

Hash.prototype = {
  _init: function (keys, items) {
    this._items = items || [];
    this._keys = keys || [];
  },
  
  get: function (key) {
    let indexOfKey = this._keys.indexOf(key);
    if (indexOfKey == -1) {
      return null;
    }
    return this._items[indexOfKey];
  },
  
  set: function (key, val) {
    let indexOfKey = this._keys.indexOf(key);
    if (indexOfKey == -1) {
      this._keys.push(key);
      this._items.push(val);
    } else {
      this._items[indexOfKey] = val;
    }
    return val;
  },
  
  remove: function (key) {
    let indexOfKey = this._keys.indexOf(key);
    if (indexOfKey != -1) {
      this._keys.splice(indexOfKey, 1);
      this._items.splice(indexOfKey, 1)[0];
      return true;
    }
    return false;
  },
  
  contains: function (key) {
    return this._keys.indexOf(key) != -1;
  },
  
  clear: function() {
    this._keys.splice(0, this._keys.length);
    this._items.splice(0, this._items.length);
  }
};